summaryrefslogtreecommitdiff
path: root/factory/base.py
diff options
context:
space:
mode:
Diffstat (limited to 'factory/base.py')
-rw-r--r--factory/base.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/factory/base.py b/factory/base.py
index d255dbf..7db0c76 100644
--- a/factory/base.py
+++ b/factory/base.py
@@ -40,7 +40,7 @@ class FactoryError(Exception):
class AssociatedClassError(FactoryError):
"""Exception for Factory subclasses lacking FACTORY_FOR."""
class UnknownStrategy(FactoryError):
@@ -82,7 +82,7 @@ class FactoryMetaClass(type):
elif cls._meta.strategy == STUB_STRATEGY:
return cls.stub(**kwargs)
else:
- raise UnknownStrategy('Unknown FACTORY_STRATEGY: {0}'.format(
+ raise UnknownStrategy('Unknown Meta.strategy: {0}'.format(
cls._meta.strategy))
def __new__(mcs, class_name, bases, attrs):
@@ -40,7 +40,7 @@ class FactoryError(Exception):
class AssociatedClassError(FactoryError):
- """Exception for Factory subclasses lacking FACTORY_FOR."""
+ """Exception for Factory subclasses lacking Meta.target."""
class UnknownStrategy(FactoryError):